/******************************************************************************
*
*  GenFXIni.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  initialization of all generators, fx, envelopes and sequencer.  called at
*  the beginning of the song before audio output.  extensive post processing
*  and analysis occurs on this function, so follow the guidelines on usage as
*  outlined in the documentation.
*
******************************************************************************/

.MODULE                                     modGenFXIni_00;

/*
 *  include files for all functions
 */
 

#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"
#include    "ag0.h"

/*
 *  external variables and functions
 */

/*
 *  entry points
 */

.ENTRY      InitGMParams_00;
.ENTRY      EndInitGMParams_00;

InitGMParams_00:
    /* insert generators and fx initializations here */
    SETPTR(a_WTGen2);
    INIT_WTGEN2(0, ^a_WTSine);
    INIT_WTGEN2(0, ^a_WTSine);
    INIT_WTGEN2(0, ^a_WTSine);
    
    SETPTR(a_ADSRPanEnv);
    INIT_ADSRPANENV(128, 0x7fff, 0x0040, 0, 0, 0, 0x4000);
    INIT_ADSRPANENV(128, 0x7fff, 0x0080, 0, 0, 0, 0x4000);
    INIT_ADSRPANENV(128, 0x7fff, 0x0100, 0, 0, 0, 0x4000);
    
           
    /* init TrigTrack and VolTrack arrays as needed */    
    AR = 100;
    AX0 = 50;
    AY0 = 0x2000;
    
    DM(a_TrigTrack00+0) = AR;
    DM(a_VolTrack00+0) = AY0;
    AY0 = 0x1800;
    DM(a_TrigTrack01+0) = AR;
    DM(a_VolTrack01+0) = AY0;
    AY0 = 0x1000;
    DM(a_TrigTrack02+2) = AR;
    DM(a_VolTrack02+2) = AY0;
    DM(a_TrigTrack02+6) = AR;
    DM(a_VolTrack02+6) = AY0;
    DM(a_TrigTrack02+7) = AR;
    DM(a_VolTrack02+7) = AY0;

    AR = 36;
    DM(a_agMedFreq+0) = AR;
    DM(a_agLastNotes+0) = AR;
    AR = 48;
    DM(a_agMedFreq+1) = AR;
    DM(a_agLastNotes+1) = AR;
    AR = 60;
    DM(a_agMedFreq+2) = AR;
    DM(a_agLastNotes+2) = AR;
    
    AR = 12;
    DM(a_agFreqRange+0) = AR;
    AR = 12;
    DM(a_agFreqRange+1) = AR;
    AR = 12;
    DM(a_agFreqRange+2) = AR;
   
    AR = 5;
    DM(a_agRandomness+0) = AR;
    AR = 7;
    DM(a_agRandomness+1) = AR;
    AR = 8;
    DM(a_agRandomness+2) = AR;
    
    AR = 20;
    DM(a_agDischordancy+0) = AR;
    AR = 20;
    DM(a_agDischordancy+1) = AR;
    AR = 40;
    DM(a_agDischordancy+2) = AR;

    
/*
 *  init sequencer array
 *  
 *  param0:  tic period
 *  param1:  swing period (num tics between slow/fast transition)
 *  param2:  swing amount
 *  param3:  sequencer length
 *  param4:  ptr to TrigInit function
 *  param5:  envelope type
 *  param6:  aux function ptr
 *
 */

    SETPTR(a_Seq2);
    modify(I2, M1);                         /* numtrax set by CalcSeq2Tracks */

    INIT_SEQ2(800, 0, 0, 1, ^InitSQ0, ADSRENV, ^DummyRet);
    INIT_SEQ2(400, 0, 0, 1, ^InitSQ1, ADSRENV, ^DummyRet);
    INIT_SEQ2(20, 0, 0, 8, ^InitSQ2, ADSRENV, ^DummyRet);

    /* must be called after Seq2 init to set env and num tracks */
    call Seq2PostProc;
    
    /* set v_TicsPerMeasure to length of first sequence */
    SEQ2_SET_MEASURE(0);

    AR = ^InitGMParams_00;
    AX0 = ^EndInitGMParams_00;
    call FillGenFXPtrInits;
    
    /* init ^Env and set length of array of ptrs used in GenFXPtrInits */
    call GenFXIniPostProc;                  /* do not remove! */
    
    /* mute tracks here */
    

EndInitGMParams_00:
    rts;

.ENDMOD;
