/******************************************************************************
*
*  SongCTRL.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  function for modifying parameters on a measure by measure basis.  execution
*  rate determined by v_TicsPerMeasure (set in GenFXIni.dsp by macros).
*
******************************************************************************/

.MODULE                                     modSongCTRL_00;

/*
 *  include files for all functions
 */


#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"
#include    "exp1_3.h"

/*
 *  external variables and functions
 */

/*
 *  entry points
 */

.ENTRY      SongCTRL_00;
.ENTRY      Measure_JT;
.ENTRY      EndMeasure_JT;

SongCTRL_00:
    AR = DM(v_TicCNTR);
    AR = AR + 1;
    DM(v_TicCNTR) = AR;
    AY0 = DM(v_TicsPerMeasure);
    AR = AR - AY0;
    if LT rts;
    
    DM(v_TicCNTR) = M0;

/*
 *  note!  this initialization used to be in InitFunc.dsp.  however, to make
 *  this function work with multiple tracks in a single executable, Measure_JT
 *  and EndMeasure_JT would need to be abstracted and inited in SongPtrs.dsp.
 *  to try and simplify and reduce the number of initializations that occur in
 *  that function, these variables were made local and it is continually
 *  re-inited here.  note that this code runs in the krate loop so performance
 *  is not a concern.
 */

SetMeasuresPerSong:
    AX0 = ^EndMeasure_JT;
    AY0 = ^Measure_JT;
    AR = AX0 - AY0;
    DM(v_MeasuresPerSong) = AR;
    
    I5 = ^Measure_JT;
    M5 = DM(v_CurrMeasure);
    modify(I5, M5);
    jump (I5);
    
/*
 *  insert JT of operations to perform at the start of every new measure
 */
    
Measure_JT:
    jump Measure1;
EndMeasure_JT:

/*
 *  insert all multimeasure operations - for parameters that should be modified
 *  over multiple measures
 */

MultiMeasureCheck:

EndSongCheck:
    AR = DM(v_CurrMeasure);
    AR = AR + 1;
    DM(v_CurrMeasure) = AR;
    AY0 = DM(v_MeasuresPerSong);
    AR = AR - AY0;
    if LT rts;

/*
 *  SongCTRL list is complete.  jumping to EndSong will start the next song
 *  in a multisong environment.  resetting CurrMeasure starts the Measure_JT
 *  loop over again, causing the same song to play indefinitely
 */
    
    !jump EndSong;
    
    DM(v_CurrMeasure) = M0;
    rts;

MultiMeasureMod:
    AR = DM(v_CurrMeasure);   
    AY0 = SR0;       
    NONE = AR - AY0;         
    if LT jump EndMMM;
    AY0 = SR1;
    NONE = AR - AY0;
    if GT jump EndMMM;
    call (I5);
EndMMM:
    rts;

Measure1:

/* OLDTRACK(CLEAR, 0, 0,  a--- ---- ---- ----  a--- ---- ---- a---,
            CLEAR, 0, 1,  ---- ---- b--- --b-  ---- ---- b--- ----,
            CLEAR, 0, 2,  ---- c--- ---- ----  ---- c--- ---- --c-,
            CLEAR, 0, 3,  --d- ---- d--- ----  d--- ---- d-d- d---,
            CLEAR, 0, 4,  --d- ---- d--- ----  d--- ---- d-d- d---,
            CLEAR, 0, 5,  ---- ---- e--- ----  ---- ---- e--- ----,
            CLEAR, 0, 6,  ---- ---- e--- ----  ---- ---- e--- ----,
            CLEAR, 0, 7,  f-f- f-f- ---- f-f-  f-ff f-f- --f- f-ff,
            CLEAR, 0, 8,  f-f- f-f- ---- f-f-  f-ff f-f- --f- f-ff,
            CLEAR, 0, 9,  g--- ---- ---- ----  ---- --g- ---- ----,
            CLEAR, 0, 10, h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-,
            CLEAR, 0, 11, h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-,
            CLEAR, 0, 12, k--- ---- ---- ----  ---- --k- ---- ----,
            CLEAR, 0, 13, l--- ---- ---- ----  ---- --l- ---- ----,
            CLEAR, 0, 14, m--- ---- --m- ----  m--- ---- m--- ----,
            CLEAR, 0, 15, ---- n--- ---- n---  ---- n--- --n- ----,
            a, 100, 0x3000,
            b, 100, 0x2000,
            c, 100, 0x0600,
            d, 100, 0x0100,
            e, 100, 0x2000,
            f, 100, 0x1800,
            g, 100, 0x0800,
            h, 100, 0x1000,
            i, 50,  0x0c00,
            j, 20,  0x0800,
            k, 100, 0x0c00,
            l, 100, 0x0700,
            m, 100, 0x0600,
            n, 100, 0x0400,
            END); */

/*
 *  autogenerated code for SETTRACK macro
 */
    I2 = ^a_TrigTrack00;
    I3 = ^a_VolTrack00;
    CNTR = 128;
    do CL00146 until CE;
        DM(I2, M1) = 0;
CL00146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack01;
    I3 = ^a_VolTrack01;
    CNTR = 128;
    do CL01146 until CE;
        DM(I2, M1) = 0;
CL01146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack02;
    I3 = ^a_VolTrack02;
    CNTR = 128;
    do CL02146 until CE;
        DM(I2, M1) = 0;
CL02146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack03;
    I3 = ^a_VolTrack03;
    CNTR = 128;
    do CL03146 until CE;
        DM(I2, M1) = 0;
CL03146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack04;
    I3 = ^a_VolTrack04;
    CNTR = 128;
    do CL04146 until CE;
        DM(I2, M1) = 0;
CL04146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack05;
    I3 = ^a_VolTrack05;
    CNTR = 128;
    do CL05146 until CE;
        DM(I2, M1) = 0;
CL05146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack06;
    I3 = ^a_VolTrack06;
    CNTR = 128;
    do CL06146 until CE;
        DM(I2, M1) = 0;
CL06146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack07;
    I3 = ^a_VolTrack07;
    CNTR = 128;
    do CL07146 until CE;
        DM(I2, M1) = 0;
CL07146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack08;
    I3 = ^a_VolTrack08;
    CNTR = 128;
    do CL08146 until CE;
        DM(I2, M1) = 0;
CL08146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack09;
    I3 = ^a_VolTrack09;
    CNTR = 128;
    do CL09146 until CE;
        DM(I2, M1) = 0;
CL09146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack10;
    I3 = ^a_VolTrack10;
    CNTR = 128;
    do CL10146 until CE;
        DM(I2, M1) = 0;
CL10146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack11;
    I3 = ^a_VolTrack11;
    CNTR = 128;
    do CL11146 until CE;
        DM(I2, M1) = 0;
CL11146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack12;
    I3 = ^a_VolTrack12;
    CNTR = 128;
    do CL12146 until CE;
        DM(I2, M1) = 0;
CL12146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack13;
    I3 = ^a_VolTrack13;
    CNTR = 128;
    do CL13146 until CE;
        DM(I2, M1) = 0;
CL13146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack14;
    I3 = ^a_VolTrack14;
    CNTR = 128;
    do CL14146 until CE;
        DM(I2, M1) = 0;
CL14146:   DM(I3, M1) = 0;

    I2 = ^a_TrigTrack15;
    I3 = ^a_VolTrack15;
    CNTR = 128;
    do CL15146 until CE;
        DM(I2, M1) = 0;
CL15146:   DM(I3, M1) = 0;

    /* inits for a */
    AX0 = 100;
    AX1 = 0x3000;
    DM(a_TrigTrack00+0+0) = AX0;
    DM(a_VolTrack00+0+0) = AX1;
    DM(a_TrigTrack00+0+16) = AX0;
    DM(a_VolTrack00+0+16) = AX1;
    DM(a_TrigTrack00+0+28) = AX0;
    DM(a_VolTrack00+0+28) = AX1;
    DM(a_TrigTrack00+0+36) = AX0;
    DM(a_VolTrack00+0+36) = AX1;
    DM(a_TrigTrack00+0+48) = AX0;
    DM(a_VolTrack00+0+48) = AX1;
    DM(a_TrigTrack00+0+60) = AX0;
    DM(a_VolTrack00+0+60) = AX1;

    /* inits for b */
    AX0 = 100;
    AX1 = 0x2000;
    DM(a_TrigTrack01+0+8) = AX0;
    DM(a_VolTrack01+0+8) = AX1;
    DM(a_TrigTrack01+0+14) = AX0;
    DM(a_VolTrack01+0+14) = AX1;
    DM(a_TrigTrack01+0+24) = AX0;
    DM(a_VolTrack01+0+24) = AX1;
    DM(a_TrigTrack01+0+38) = AX0;
    DM(a_VolTrack01+0+38) = AX1;
    DM(a_TrigTrack01+0+46) = AX0;
    DM(a_VolTrack01+0+46) = AX1;
    DM(a_TrigTrack01+0+56) = AX0;
    DM(a_VolTrack01+0+56) = AX1;
    DM(a_TrigTrack01+0+62) = AX0;
    DM(a_VolTrack01+0+62) = AX1;

    /* inits for c */
    AX0 = 100;
    AX1 = 0x0600;
    DM(a_TrigTrack02+0+4) = AX0;
    DM(a_VolTrack02+0+4) = AX1;
    DM(a_TrigTrack02+0+20) = AX0;
    DM(a_VolTrack02+0+20) = AX1;
    DM(a_TrigTrack02+0+30) = AX0;
    DM(a_VolTrack02+0+30) = AX1;
    DM(a_TrigTrack02+0+44) = AX0;
    DM(a_VolTrack02+0+44) = AX1;
    DM(a_TrigTrack02+0+52) = AX0;
    DM(a_VolTrack02+0+52) = AX1;
    DM(a_TrigTrack02+0+62) = AX0;
    DM(a_VolTrack02+0+62) = AX1;

    /* inits for d */
    AX0 = 100;
    AX1 = 0x0100;
    DM(a_TrigTrack03+0+2) = AX0;
    DM(a_VolTrack03+0+2) = AX1;
    DM(a_TrigTrack04+0+2) = AX0;
    DM(a_VolTrack04+0+2) = AX1;
    DM(a_TrigTrack03+0+8) = AX0;
    DM(a_VolTrack03+0+8) = AX1;
    DM(a_TrigTrack04+0+8) = AX0;
    DM(a_VolTrack04+0+8) = AX1;
    DM(a_TrigTrack03+0+16) = AX0;
    DM(a_VolTrack03+0+16) = AX1;
    DM(a_TrigTrack04+0+16) = AX0;
    DM(a_VolTrack04+0+16) = AX1;
    DM(a_TrigTrack03+0+24) = AX0;
    DM(a_VolTrack03+0+24) = AX1;
    DM(a_TrigTrack04+0+24) = AX0;
    DM(a_VolTrack04+0+24) = AX1;
    DM(a_TrigTrack03+0+26) = AX0;
    DM(a_VolTrack03+0+26) = AX1;
    DM(a_TrigTrack04+0+26) = AX0;
    DM(a_VolTrack04+0+26) = AX1;
    DM(a_TrigTrack03+0+28) = AX0;
    DM(a_VolTrack03+0+28) = AX1;
    DM(a_TrigTrack04+0+28) = AX0;
    DM(a_VolTrack04+0+28) = AX1;
    DM(a_TrigTrack03+0+34) = AX0;
    DM(a_VolTrack03+0+34) = AX1;
    DM(a_TrigTrack04+0+34) = AX0;
    DM(a_VolTrack04+0+34) = AX1;
    DM(a_TrigTrack03+0+40) = AX0;
    DM(a_VolTrack03+0+40) = AX1;
    DM(a_TrigTrack04+0+40) = AX0;
    DM(a_VolTrack04+0+40) = AX1;
    DM(a_TrigTrack03+0+48) = AX0;
    DM(a_VolTrack03+0+48) = AX1;
    DM(a_TrigTrack04+0+48) = AX0;
    DM(a_VolTrack04+0+48) = AX1;
    DM(a_TrigTrack03+0+56) = AX0;
    DM(a_VolTrack03+0+56) = AX1;
    DM(a_TrigTrack04+0+56) = AX0;
    DM(a_VolTrack04+0+56) = AX1;
    DM(a_TrigTrack03+0+58) = AX0;
    DM(a_VolTrack03+0+58) = AX1;
    DM(a_TrigTrack04+0+58) = AX0;
    DM(a_VolTrack04+0+58) = AX1;
    DM(a_TrigTrack03+0+60) = AX0;
    DM(a_VolTrack03+0+60) = AX1;
    DM(a_TrigTrack04+0+60) = AX0;
    DM(a_VolTrack04+0+60) = AX1;

    /* inits for e */
    AX0 = 100;
    AX1 = 0x2000;
    DM(a_TrigTrack05+0+8) = AX0;
    DM(a_VolTrack05+0+8) = AX1;
    DM(a_TrigTrack06+0+8) = AX0;
    DM(a_VolTrack06+0+8) = AX1;
    DM(a_TrigTrack05+0+24) = AX0;
    DM(a_VolTrack05+0+24) = AX1;
    DM(a_TrigTrack06+0+24) = AX0;
    DM(a_VolTrack06+0+24) = AX1;
    DM(a_TrigTrack05+0+40) = AX0;
    DM(a_VolTrack05+0+40) = AX1;
    DM(a_TrigTrack06+0+40) = AX0;
    DM(a_VolTrack06+0+40) = AX1;
    DM(a_TrigTrack05+0+56) = AX0;
    DM(a_VolTrack05+0+56) = AX1;
    DM(a_TrigTrack06+0+56) = AX0;
    DM(a_VolTrack06+0+56) = AX1;

    /* inits for f */
    AX0 = 100;
    AX1 = 0x1800;
    DM(a_TrigTrack07+0+0) = AX0;
    DM(a_VolTrack07+0+0) = AX1;
    DM(a_TrigTrack08+0+0) = AX0;
    DM(a_VolTrack08+0+0) = AX1;
    DM(a_TrigTrack07+0+2) = AX0;
    DM(a_VolTrack07+0+2) = AX1;
    DM(a_TrigTrack08+0+2) = AX0;
    DM(a_VolTrack08+0+2) = AX1;
    DM(a_TrigTrack07+0+4) = AX0;
    DM(a_VolTrack07+0+4) = AX1;
    DM(a_TrigTrack08+0+4) = AX0;
    DM(a_VolTrack08+0+4) = AX1;
    DM(a_TrigTrack07+0+6) = AX0;
    DM(a_VolTrack07+0+6) = AX1;
    DM(a_TrigTrack08+0+6) = AX0;
    DM(a_VolTrack08+0+6) = AX1;
    DM(a_TrigTrack07+0+12) = AX0;
    DM(a_VolTrack07+0+12) = AX1;
    DM(a_TrigTrack08+0+12) = AX0;
    DM(a_VolTrack08+0+12) = AX1;
    DM(a_TrigTrack07+0+14) = AX0;
    DM(a_VolTrack07+0+14) = AX1;
    DM(a_TrigTrack08+0+14) = AX0;
    DM(a_VolTrack08+0+14) = AX1;
    DM(a_TrigTrack07+0+16) = AX0;
    DM(a_VolTrack07+0+16) = AX1;
    DM(a_TrigTrack08+0+16) = AX0;
    DM(a_VolTrack08+0+16) = AX1;
    DM(a_TrigTrack07+0+18) = AX0;
    DM(a_VolTrack07+0+18) = AX1;
    DM(a_TrigTrack08+0+18) = AX0;
    DM(a_VolTrack08+0+18) = AX1;
    DM(a_TrigTrack07+0+19) = AX0;
    DM(a_VolTrack07+0+19) = AX1;
    DM(a_TrigTrack08+0+19) = AX0;
    DM(a_VolTrack08+0+19) = AX1;
    DM(a_TrigTrack07+0+20) = AX0;
    DM(a_VolTrack07+0+20) = AX1;
    DM(a_TrigTrack08+0+20) = AX0;
    DM(a_VolTrack08+0+20) = AX1;
    DM(a_TrigTrack07+0+22) = AX0;
    DM(a_VolTrack07+0+22) = AX1;
    DM(a_TrigTrack08+0+22) = AX0;
    DM(a_VolTrack08+0+22) = AX1;
    DM(a_TrigTrack07+0+26) = AX0;
    DM(a_VolTrack07+0+26) = AX1;
    DM(a_TrigTrack08+0+26) = AX0;
    DM(a_VolTrack08+0+26) = AX1;
    DM(a_TrigTrack07+0+28) = AX0;
    DM(a_VolTrack07+0+28) = AX1;
    DM(a_TrigTrack08+0+28) = AX0;
    DM(a_VolTrack08+0+28) = AX1;
    DM(a_TrigTrack07+0+30) = AX0;
    DM(a_VolTrack07+0+30) = AX1;
    DM(a_TrigTrack08+0+30) = AX0;
    DM(a_VolTrack08+0+30) = AX1;
    DM(a_TrigTrack07+0+31) = AX0;
    DM(a_VolTrack07+0+31) = AX1;
    DM(a_TrigTrack08+0+31) = AX0;
    DM(a_VolTrack08+0+31) = AX1;
    DM(a_TrigTrack07+0+32) = AX0;
    DM(a_VolTrack07+0+32) = AX1;
    DM(a_TrigTrack08+0+32) = AX0;
    DM(a_VolTrack08+0+32) = AX1;
    DM(a_TrigTrack07+0+34) = AX0;
    DM(a_VolTrack07+0+34) = AX1;
    DM(a_TrigTrack08+0+34) = AX0;
    DM(a_VolTrack08+0+34) = AX1;
    DM(a_TrigTrack07+0+36) = AX0;
    DM(a_VolTrack07+0+36) = AX1;
    DM(a_TrigTrack08+0+36) = AX0;
    DM(a_VolTrack08+0+36) = AX1;
    DM(a_TrigTrack07+0+37) = AX0;
    DM(a_VolTrack07+0+37) = AX1;
    DM(a_TrigTrack08+0+37) = AX0;
    DM(a_VolTrack08+0+37) = AX1;
    DM(a_TrigTrack07+0+38) = AX0;
    DM(a_VolTrack07+0+38) = AX1;
    DM(a_TrigTrack08+0+38) = AX0;
    DM(a_VolTrack08+0+38) = AX1;
    DM(a_TrigTrack07+0+40) = AX0;
    DM(a_VolTrack07+0+40) = AX1;
    DM(a_TrigTrack08+0+40) = AX0;
    DM(a_VolTrack08+0+40) = AX1;
    DM(a_TrigTrack07+0+44) = AX0;
    DM(a_VolTrack07+0+44) = AX1;
    DM(a_TrigTrack08+0+44) = AX0;
    DM(a_VolTrack08+0+44) = AX1;
    DM(a_TrigTrack07+0+48) = AX0;
    DM(a_VolTrack07+0+48) = AX1;
    DM(a_TrigTrack08+0+48) = AX0;
    DM(a_VolTrack08+0+48) = AX1;
    DM(a_TrigTrack07+0+50) = AX0;
    DM(a_VolTrack07+0+50) = AX1;
    DM(a_TrigTrack08+0+50) = AX0;
    DM(a_VolTrack08+0+50) = AX1;
    DM(a_TrigTrack07+0+51) = AX0;
    DM(a_VolTrack07+0+51) = AX1;
    DM(a_TrigTrack08+0+51) = AX0;
    DM(a_VolTrack08+0+51) = AX1;
    DM(a_TrigTrack07+0+54) = AX0;
    DM(a_VolTrack07+0+54) = AX1;
    DM(a_TrigTrack08+0+54) = AX0;
    DM(a_VolTrack08+0+54) = AX1;
    DM(a_TrigTrack07+0+56) = AX0;
    DM(a_VolTrack07+0+56) = AX1;
    DM(a_TrigTrack08+0+56) = AX0;
    DM(a_VolTrack08+0+56) = AX1;
    DM(a_TrigTrack07+0+58) = AX0;
    DM(a_VolTrack07+0+58) = AX1;
    DM(a_TrigTrack08+0+58) = AX0;
    DM(a_VolTrack08+0+58) = AX1;
    DM(a_TrigTrack07+0+60) = AX0;
    DM(a_VolTrack07+0+60) = AX1;
    DM(a_TrigTrack08+0+60) = AX0;
    DM(a_VolTrack08+0+60) = AX1;
    DM(a_TrigTrack07+0+62) = AX0;
    DM(a_VolTrack07+0+62) = AX1;
    DM(a_TrigTrack08+0+62) = AX0;
    DM(a_VolTrack08+0+62) = AX1;
    DM(a_TrigTrack07+0+63) = AX0;
    DM(a_VolTrack07+0+63) = AX1;
    DM(a_TrigTrack08+0+63) = AX0;
    DM(a_VolTrack08+0+63) = AX1;

    /* inits for g */
    AX0 = 100;
    AX1 = 0x0c00;
    DM(a_TrigTrack09+0+0) = AX0;
    DM(a_VolTrack09+0+0) = AX1;
    DM(a_TrigTrack09+0+22) = AX0;
    DM(a_VolTrack09+0+22) = AX1;
    DM(a_TrigTrack09+0+32) = AX0;
    DM(a_VolTrack09+0+32) = AX1;
    DM(a_TrigTrack09+0+54) = AX0;
    DM(a_VolTrack09+0+54) = AX1;

    /* inits for h */
    AX0 = 100;
    AX1 = 0x1000;
    DM(a_TrigTrack10+0+0) = AX0;
    DM(a_VolTrack10+0+0) = AX1;
    DM(a_TrigTrack11+0+0) = AX0;
    DM(a_VolTrack11+0+0) = AX1;
    DM(a_TrigTrack10+0+12) = AX0;
    DM(a_VolTrack10+0+12) = AX1;
    DM(a_TrigTrack11+0+12) = AX0;
    DM(a_VolTrack11+0+12) = AX1;
    DM(a_TrigTrack10+0+24) = AX0;
    DM(a_VolTrack10+0+24) = AX1;
    DM(a_TrigTrack11+0+24) = AX0;
    DM(a_VolTrack11+0+24) = AX1;
    DM(a_TrigTrack10+0+32) = AX0;
    DM(a_VolTrack10+0+32) = AX1;
    DM(a_TrigTrack11+0+32) = AX0;
    DM(a_VolTrack11+0+32) = AX1;
    DM(a_TrigTrack10+0+44) = AX0;
    DM(a_VolTrack10+0+44) = AX1;
    DM(a_TrigTrack11+0+44) = AX0;
    DM(a_VolTrack11+0+44) = AX1;
    DM(a_TrigTrack10+0+56) = AX0;
    DM(a_VolTrack10+0+56) = AX1;
    DM(a_TrigTrack11+0+56) = AX0;
    DM(a_VolTrack11+0+56) = AX1;

    /* inits for i */
    AX0 = 50;
    AX1 = 0x0c00;
    DM(a_TrigTrack10+0+2) = AX0;
    DM(a_VolTrack10+0+2) = AX1;
    DM(a_TrigTrack11+0+2) = AX0;
    DM(a_VolTrack11+0+2) = AX1;
    DM(a_TrigTrack10+0+4) = AX0;
    DM(a_VolTrack10+0+4) = AX1;
    DM(a_TrigTrack11+0+4) = AX0;
    DM(a_VolTrack11+0+4) = AX1;
    DM(a_TrigTrack10+0+10) = AX0;
    DM(a_VolTrack10+0+10) = AX1;
    DM(a_TrigTrack11+0+10) = AX0;
    DM(a_VolTrack11+0+10) = AX1;
    DM(a_TrigTrack10+0+14) = AX0;
    DM(a_VolTrack10+0+14) = AX1;
    DM(a_TrigTrack11+0+14) = AX0;
    DM(a_VolTrack11+0+14) = AX1;
    DM(a_TrigTrack10+0+16) = AX0;
    DM(a_VolTrack10+0+16) = AX1;
    DM(a_TrigTrack11+0+16) = AX0;
    DM(a_VolTrack11+0+16) = AX1;
    DM(a_TrigTrack10+0+20) = AX0;
    DM(a_VolTrack10+0+20) = AX1;
    DM(a_TrigTrack11+0+20) = AX0;
    DM(a_VolTrack11+0+20) = AX1;
    DM(a_TrigTrack10+0+26) = AX0;
    DM(a_VolTrack10+0+26) = AX1;
    DM(a_TrigTrack11+0+26) = AX0;
    DM(a_VolTrack11+0+26) = AX1;
    DM(a_TrigTrack10+0+34) = AX0;
    DM(a_VolTrack10+0+34) = AX1;
    DM(a_TrigTrack11+0+34) = AX0;
    DM(a_VolTrack11+0+34) = AX1;
    DM(a_TrigTrack10+0+36) = AX0;
    DM(a_VolTrack10+0+36) = AX1;
    DM(a_TrigTrack11+0+36) = AX0;
    DM(a_VolTrack11+0+36) = AX1;
    DM(a_TrigTrack10+0+42) = AX0;
    DM(a_VolTrack10+0+42) = AX1;
    DM(a_TrigTrack11+0+42) = AX0;
    DM(a_VolTrack11+0+42) = AX1;
    DM(a_TrigTrack10+0+46) = AX0;
    DM(a_VolTrack10+0+46) = AX1;
    DM(a_TrigTrack11+0+46) = AX0;
    DM(a_VolTrack11+0+46) = AX1;
    DM(a_TrigTrack10+0+48) = AX0;
    DM(a_VolTrack10+0+48) = AX1;
    DM(a_TrigTrack11+0+48) = AX0;
    DM(a_VolTrack11+0+48) = AX1;
    DM(a_TrigTrack10+0+52) = AX0;
    DM(a_VolTrack10+0+52) = AX1;
    DM(a_TrigTrack11+0+52) = AX0;
    DM(a_VolTrack11+0+52) = AX1;
    DM(a_TrigTrack10+0+58) = AX0;
    DM(a_VolTrack10+0+58) = AX1;
    DM(a_TrigTrack11+0+58) = AX0;
    DM(a_VolTrack11+0+58) = AX1;

    /* inits for j */
    AX0 = 20;
    AX1 = 0x0800;
    DM(a_TrigTrack10+0+8) = AX0;
    DM(a_VolTrack10+0+8) = AX1;
    DM(a_TrigTrack11+0+8) = AX0;
    DM(a_VolTrack11+0+8) = AX1;
    DM(a_TrigTrack10+0+22) = AX0;
    DM(a_VolTrack10+0+22) = AX1;
    DM(a_TrigTrack11+0+22) = AX0;
    DM(a_VolTrack11+0+22) = AX1;
    DM(a_TrigTrack10+0+28) = AX0;
    DM(a_VolTrack10+0+28) = AX1;
    DM(a_TrigTrack11+0+28) = AX0;
    DM(a_VolTrack11+0+28) = AX1;
    DM(a_TrigTrack10+0+30) = AX0;
    DM(a_VolTrack10+0+30) = AX1;
    DM(a_TrigTrack11+0+30) = AX0;
    DM(a_VolTrack11+0+30) = AX1;
    DM(a_TrigTrack10+0+40) = AX0;
    DM(a_VolTrack10+0+40) = AX1;
    DM(a_TrigTrack11+0+40) = AX0;
    DM(a_VolTrack11+0+40) = AX1;
    DM(a_TrigTrack10+0+54) = AX0;
    DM(a_VolTrack10+0+54) = AX1;
    DM(a_TrigTrack11+0+54) = AX0;
    DM(a_VolTrack11+0+54) = AX1;
    DM(a_TrigTrack10+0+60) = AX0;
    DM(a_VolTrack10+0+60) = AX1;
    DM(a_TrigTrack11+0+60) = AX0;
    DM(a_VolTrack11+0+60) = AX1;
    DM(a_TrigTrack10+0+62) = AX0;
    DM(a_VolTrack10+0+62) = AX1;
    DM(a_TrigTrack11+0+62) = AX0;
    DM(a_VolTrack11+0+62) = AX1;

    /* inits for k */
    AX0 = 100;
    AX1 = 0x0c00;
    DM(a_TrigTrack12+0+0) = AX0;
    DM(a_VolTrack12+0+0) = AX1;
    DM(a_TrigTrack12+0+22) = AX0;
    DM(a_VolTrack12+0+22) = AX1;
    DM(a_TrigTrack12+0+32) = AX0;
    DM(a_VolTrack12+0+32) = AX1;
    DM(a_TrigTrack12+0+54) = AX0;
    DM(a_VolTrack12+0+54) = AX1;

    /* inits for l */
    AX0 = 100;
    AX1 = 0x0700;
    DM(a_TrigTrack13+0+0) = AX0;
    DM(a_VolTrack13+0+0) = AX1;
    DM(a_TrigTrack13+0+22) = AX0;
    DM(a_VolTrack13+0+22) = AX1;
    DM(a_TrigTrack13+0+32) = AX0;
    DM(a_VolTrack13+0+32) = AX1;
    DM(a_TrigTrack13+0+54) = AX0;
    DM(a_VolTrack13+0+54) = AX1;

    /* inits for m */
    AX0 = 100;
    AX1 = 0x0500;
    DM(a_TrigTrack14+0+0) = AX0;
    DM(a_VolTrack14+0+0) = AX1;
    DM(a_TrigTrack14+0+10) = AX0;
    DM(a_VolTrack14+0+10) = AX1;
    DM(a_TrigTrack14+0+16) = AX0;
    DM(a_VolTrack14+0+16) = AX1;
    DM(a_TrigTrack14+0+24) = AX0;
    DM(a_VolTrack14+0+24) = AX1;
    DM(a_TrigTrack14+0+32) = AX0;
    DM(a_VolTrack14+0+32) = AX1;
    DM(a_TrigTrack14+0+42) = AX0;
    DM(a_VolTrack14+0+42) = AX1;
    DM(a_TrigTrack14+0+48) = AX0;
    DM(a_VolTrack14+0+48) = AX1;
    DM(a_TrigTrack14+0+60) = AX0;
    DM(a_VolTrack14+0+60) = AX1;

    /* inits for n */
    AX0 = 100;
    AX1 = 0x0400;
    DM(a_TrigTrack15+0+4) = AX0;
    DM(a_VolTrack15+0+4) = AX1;
    DM(a_TrigTrack15+0+12) = AX0;
    DM(a_VolTrack15+0+12) = AX1;
    DM(a_TrigTrack15+0+20) = AX0;
    DM(a_VolTrack15+0+20) = AX1;
    DM(a_TrigTrack15+0+26) = AX0;
    DM(a_VolTrack15+0+26) = AX1;
    DM(a_TrigTrack15+0+36) = AX0;
    DM(a_VolTrack15+0+36) = AX1;
    DM(a_TrigTrack15+0+44) = AX0;
    DM(a_VolTrack15+0+44) = AX1;
    DM(a_TrigTrack15+0+52) = AX0;
    DM(a_VolTrack15+0+52) = AX1;
    DM(a_TrigTrack15+0+58) = AX0;
    DM(a_VolTrack15+0+58) = AX1;

/* donotparse(CLEAR, 0, 0,  a--- ---- ---- ----  a--- ---- ---- a---   ---- a--- ---- ----  a--- ---- ---- a---,
            CLEAR, 0, 1,  ---- ---- b--- --b-  ---- ---- b--- ----   ---- --b- ---- --b-  ---- ---- b--- --b-,
            CLEAR, 0, 2,  ---- c--- ---- ----  ---- c--- ---- --c-   ---- ---- ---- c---  ---- c--- ---- --c-,
            CLEAR, 0, 3,  --d- ---- d--- ----  d--- ---- d-d- d---   --d- ---- d--- ----  d--- ---- d-d- d---,
            CLEAR, 0, 4,  --d- ---- d--- ----  d--- ---- d-d- d---   --d- ---- d--- ----  d--- ---- d-d- d---,
            CLEAR, 0, 5,  ---- ---- e--- ----  ---- ---- e--- ----   ---- ---- e--- ----  ---- ---- e--- ----,
            CLEAR, 0, 6,  ---- ---- e--- ----  ---- ---- e--- ----   ---- ---- e--- ----  ---- ---- e--- ----,
            CLEAR, 0, 7,  f-f- f-f- ---- f-f-  f-ff f-f- --f- f-ff   f-f- fff- f--- f---  f-ff --f- f-f- f-ff,
            CLEAR, 0, 8,  f-f- f-f- ---- f-f-  f-ff f-f- --f- f-ff   f-f- fff- f--- f---  f-ff --f- f-f- f-ff,
            CLEAR, 0, 9,  g--- ---- ---- ----  ---- --g- ---- ----   g--- ---- ---- ----  ---- --g- ---- ----,
            CLEAR, 0, 10, h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-   h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-,
            CLEAR, 0, 11, h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-   h-i- i--- j-i- h-i-  i--- i-j- h-i- j-j-,
            CLEAR, 0, 12, k--- ---- ---- ----  ---- --k- ---- ----   k--- ---- ---- ----  ---- --k- ---- ----,
            CLEAR, 0, 13, l--- ---- ---- ----  ---- --l- ---- ----   l--- ---- ---- ----  ---- --l- ---- ----,
            CLEAR, 0, 14, m--- ---- --m- ----  m--- ---- m--- ----   m--- ---- --m- ----  m--- ---- ---- m---,
            CLEAR, 0, 15, ---- n--- ---- n---  ---- n--- --n- ----   ---- n--- ---- n---  ---- n--- --n- ----,
            a, 100, 0x3000,
            b, 100, 0x2000,
            c, 100, 0x0600,
            d, 100, 0x0100,
            e, 100, 0x2000,
            f, 100, 0x1800,
            g, 100, 0x0c00,
            h, 100, 0x1000,
            i, 50,  0x0c00,
            j, 20,  0x0800,
            k, 100, 0x0c00,
            l, 100, 0x0700,
            m, 100, 0x0500,
            n, 100, 0x0400,
            END); */

    jump MultiMeasureCheck;

.ENDMOD;
