/*****************************************************************************
*
*  gmISRs.dsp
*
*  (c) 2002-2004 ethan bordeaux
*  syndevkit@dspmusic.org
*
*
*****************************************************************************/

.MODULE                                     mod_gmISRs;

#include    ".\comsys\hdr\comsym.h"
#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"
#include    ".\ez81sys\hdr\ez81sym.h"

.ENTRY      TX0ISR;              
.ENTRY      GetSamples;                 
.ENTRY      GetRandomVal;

/******************************************************************************
*
*  SPORT0 RX ISR.  currently the RX interrupt is used to send data from the DSP
*  to the CODECs, but no input information is gathered from the CODECs to the
*  DSP.  this functionality is used for two reasons:
*
*    (a)  this is how it's done in the original talkthru  :)
*    (b)  at some point it would be good to ues feedback in some algorithms
*
*  the data received is placed in two locations of DM and not touched again at
*  this point.  transmitted data comes from the LCH & RCH variables.
*
******************************************************************************/
 
GetSamples:
	ena SEC_REG;
	ena AR_SAT;
    MY0 = I7;                               /* save I7 */
    MY1 = L7;                               /* save L7 */
    
    /* read output from buffer earmarked for transmission */
    I7 = DM(p_LBuffToTX);
    L7 = OUTBUFFLEN;
    AR = DM(I7, M7);
    DM(p_LBuffToTX) = I7;                   /* p_LBuff++ */
    
    SR0 = DM(v_AllMute);
    AF = pass SR0;
    if EQ AR = pass 0;
    DM(a_TXbuffer + 1) = AR;                /* send left channel data */
    
    I7 = DM(p_RBuffToTX);
    L7 = OUTBUFFLEN;
    AR = DM(I7, M7);
    DM(p_RBuffToTX) = I7;                   /* p_RBuff++ */
    
    SR0 = DM(v_AllMute);
    AF = pass SR0;
    if EQ AR = pass 0;
    
    DM(a_TXbuffer + 2) = AR;                /* send right channel data */    
    
    /* check if end of transmission buffer was reached */
    AY0 = ^a_ROutBuff0;
    AX0 = DM(v_TXBuff0or1);
    AR = pass AX0;
    if EQ jump CheckBuffWraparound;
    
    AY0 = ^a_ROutBuff1;                     /* oops, it's Buff1 */    
    
CheckBuffWraparound:
    AX1 = I7;
    AR = AX1 - AY0;
    if NE jump EndSendMusic;
    
/*
 *  set FillNewBuffer bit, swap buffer pointers, and toggle OutBuff0or1
 *  indicator.
 */
    
SwapBuffers:
    AR = tglbit 0 of AX0;                   /* AX0=v_TXBuff0or1 */
    DM(v_TXBuff0or1) = AR;
    DM(b_FillNewBuffer) = M1;               /* time to fill data buff */
    
    AY0 = ^a_LOutBuff0;
    AY1 = ^a_ROutBuff0;
    NONE = pass AR;
    if EQ jump SetBufferPtr;
    
    AY0 = ^a_LOutBuff1;
    AY1 = ^a_ROutBuff1;
    
SetBufferPtr:
    DM(p_LBuffToTX) = AY0;
    DM(p_RBuffToTX) = AY1;
    
EndSendMusic:
    I7 = MY0;
    L7 = MY1;
    
	rti;
	
/******************************************************************************
*
*  SPORT0 TX ISR.  the TX interrupt is only used during the initialization of
*  the 1847, not during normal data transmissions.  command words are sent from
*  the a_1847Params buffer.  if the pointer to this buffer points back to the
*  beginning of the buffer, set status flag indicating all commands are sent &
*  allow for data to be transferred.  I4 ends up back at the beginning because,
*  duh, it's a circular buffer.
*
******************************************************************************/

TX0ISR:
    ena SEC_REG;
    
    AR = DM(b_Init1847);
    AR = pass AR;
    if EQ rti;
    
    AX0 = DM(I4, M7);                   /* get command word form a_1847Params */
    DM(a_TXbuffer) = AX0;               /* place command word in tx slot 0 */
    AX0 = I4;
    AY0 = ^a_1847Params;
    AR = AX0 - AY0;
    if GT rti;                          /* if eq done sending commands, else */
                                        /*   wait for next TX word/int */
    AX0 = 0xaf00;                       /* set done flag and remove MCE */
    DM(a_TXbuffer) = AX0;
    AX0 = 0;
    DM(b_Init1847) = AX0;               /* reset status flag */
    
    rti;


/******************************************************************************
*
*  IRQE ISR.  provide seed for random number generator
*
******************************************************************************/

GetRandomVal:
    ena SEC_REG;

    AR = DM(TCOUNT);
    DM(v_LSWSeed) = AR;
    DM(b_SeedCaptured) = M1;

    call IRQEProc;                      /* additional IRQE processing */

    rti;

.ENDMOD;
