/******************************************************************************
*
*  gmInit.dsp
*
*  (c) 2002-2004 ethan bordeaux
*  syndevkit@dspmusic.org
*
*
******************************************************************************/

.MODULE                                     mod_gmInit;

/*
 *  include files for all functions
 */

#include    ".\gen_fx\hdr\GenFX.h"
#include    ".\ez81sys\hdr\ez81sym.h"
#include    ".\comsys\hdr\comsym.h"
#include    ".\comsys\hdr\DSPdefs.h"

/*
 *  entry points
 */

.ENTRY      main;
.ENTRY      FRL;

/*
 *  start initialization of processor
 */

main:
    reset FL1;
	I0 = ^a_RXbuffer;
	L0 = %a_RXbuffer;
	I1 = ^a_TXbuffer;
	L1 = %a_TXbuffer;
	I4 = ^a_1847Params;
	L4 = %a_1847Params;

    /* crazy init thing for WTGen2/LFO3 - WT[0] must equal WT[128] */
    AR = DM(a_WTSine + 0);
    DM(a_WTSine + 128) = AR;
    AR = DM(a_WTSaw + 0);
    DM(a_WTSaw + 128) = AR;
    AR = DM(a_WTSq + 0);
    DM(a_WTSq + 128) = AR;
    AR = DM(a_WTTri + 0);
    DM(a_WTTri + 128) = AR;
	
	/* these modifiers are assumed true when entering every function */
	M1 = 1;
	M0 = 0;
	M6 = 0;
    M7 = 1;
    
    /* all free pointers assumed to be non-circular arrays */
    L2 = 0;
    L3 = 0;
    L5 = 0;
    L6 = 0;
    
    /* level sensitive ints, no nesting */
	IFC = 0xff;
	nop;
	ICNTL = 0;
	
	/* always assume ALU sat enabled */
    ena AR_SAT;
    ena G_MODE;
    dis M_MODE;
    
    /* 7 IO wait states, 0 DM wait states */
    AR = 0x0fff;
    DM(WAIT_STATE) = AR;
	AR = 0x1000;
	DM(SYSTEM_CONTROL) = AR;
	
	/* init to zero, proc loop runs until 1 */
	DM(b_EndSong) = M0;
	
    call InitOutBuffs;

/* This code configures the serial ports on the DSP. The serial ports are 
 * configured by writing to memory mapped control registers. SPORT0 is
 * configured to use autobuffering and multi-channel mode with an external
 * serial clock and external frame sync. Autobuffering can be thought of as
 * serial port DMA. The serial port uses the address generators to access data
 * memory automatically. In this program autobuffering is configured to use
 * I0, I1, and m1. These are data address generator registers.  I0 points to
 * the a_RXbuffer buffer, I1 points to the a_TXbuffer buffer and m1 = 1.
 * Multi-channel mode is enabled and configured for 32 channels. The AD1847 is
 * also configured for 32 channels. In Multi-channel mode each channel is a
 * word and associated with a time slot. In each of the 32 time slot the serial
 * port can transmit and/or receive data or do nothing, tristating the data
 * for that time slot. One frame consists of all 32 channels. One frame sync
 * will start a frame transfer (all 32 words). This program configures the
 * serial port 0 to transmit on channels 0, 1, 2, 16, 17 and 18 for transmit
 * and channels 0, 1, 2, 16, 17, and 18 for receive. It will ignore all other
 * time slots.  External serial clock and external frame-syncs mean they are
 * inputs to the DSP.
 */

	AX0 =0x287;   
	DM(SPORT0_AUTOBUF) = AX0;       /*  enable receive and transmit autobuff,
					                 *  RMREG=M1, RIREG=I0, TMREG=M1, TIREG=I1,
					                 *  CLKOUT enabled, BIASRND disabled  */

	AX0 = 0;         
	DM(SPORT0_RFSDIV) = AX0;        /*  RFSDIV = SCLK Hz/RFS Hz - 1 
					                 *  using ext rx frame sync (RFS=input) */

	AX0 = 0;         
	DM(SPORT0_SCLKDIV) = AX0;       /*  SCLK = CLKOUT/(2*(SCLKDIV + 1)) 
                                     *  using ext serial clock (SCLK=input) */

	AX0 =0x860f;   
	DM(SPORT0_CONTROL) = AX0;       /*  SLEN = 16 bits, right justify,
                                     *         zero-fill unused MSBs,
                                     *  INVRFS=0, INVTFS=0, IRFS=0, ITFS=1, 
					                 *  MFD=1, ISCLK=0, MCE=1 */

	AX0 =0x7;      
    DM(SPORT0_TX_CHANNELS0) = AX0;  /* enable channels 0, 1 and 2 for tx */

	AX0 =0x7;      
	DM(SPORT0_TX_CHANNELS1) = AX0;  /* enable channels 16, 17 and 18 for tx */

	AX0 =0x7;      
	DM(SPORT0_RX_CHANNELS0) = AX0;  /* enable channels 0, 1 and 2 for rx */

	AX0 =0x7;
	DM(SPORT0_RX_CHANNELS1) = AX0;  /* enable channels 16, 17 and 18 for rx */


	AX0 = 0x1000;                   /* PWAIT = 0, enable SPORT0 */
	DM(SYSTEM_CONTROL) = AX0;

	IMASK = SPORT0TX_IRQ;           /* unmask SPORT0s transmit interrupt */
	AX0 = DM(I1, M1);               /* set AX0 = the first val in a_TXbuffer */
	TX0 = AX0;                      /* begin autobuffer tx by writing first */
	                                /*   value to TX0 reg (when autobuff tx */
	                                /*   completes a tx int is generated */

/*
 *  test for entire a_1847Params buffer to be sent to the codec
 */

CheckSPortInit:
    AX0 = DM(b_Init1847);           /* AX0=stat_flag - clr in SPORT0 tx isr */      
    AF = pass AX0;
    if NE jump CheckSPortInit;

/*
 *  once tx completes, wait for codec to come out of autocalibration by
 *  testing ACI bit in AD1847s status reg.  this is done twice, first to ensure
 *  the codec is in autocalibration mode, then to determine when
 *  autocalibration is complete.
 */

	AY0 = 2;

CheckACI1:                              /* ACI bit=1 (in autocal)*/
	AX0 = DM(a_RXbuffer);               /* read status word of AD1847 */              
	AR = AX0 and AY0;                   /* test bit 1 of status word */
	if EQ jump CheckACI1;

CheckACI2:                              /* ACI bit=0 (autocal complete) */
	AX0 = DM(a_RXbuffer);	
	AR = AX0 and AY0;
	if NE jump CheckACI2;

/*
 *  once autocalibration is complete unmute left and right DAC channels by
 *  writing the appropriate index register
 */

	AY0 = 0xbf3f;                   /* unmute left DAC */
	AX0 = DM(a_1847Params + 6);
	AR = AX0 and AY0;
	DM(a_TXbuffer) = AR;	
	idle;                           /* wait for tx to complete */
	
	AX0 = DM(a_1847Params + 7);     /* unmute right DAC */
	AR = AX0 and AY0;
	DM (a_TXbuffer) = AR;	
	idle;                           /* wait for tx to complete */

    IFC = 0xff;                     /* clear any pending interrupt */
    nop;
    IMASK = IRQE_IRQ|SPORT0RX_IRQ;
    
    /* set up timer to generate "random" seed.  wait to fill random buff. */
    AR = 0xffff;
    DM(TPERIOD) = AR;
    DM(TCOUNT) = AR;
    DM(TSCALE) = M0;
    ena TIMER;

/*
 *  comment this code out to avoid using IRQE to capture a seed for the RNG
 */

/*
W1: AR = DM(b_SeedCaptured);
    AR = pass AR;
    if EQ jump W1;
*/

    AF = pass 0;
    I5 = ^CurrSongJT;

CountSongs:
    AR = PM(I5, M7);
    AR = AR - 0x2000;
    if GT jump EndSongCount;
    AF = AF + 1;
    jump CountSongs;
    
EndSongCount:
    AR = pass AF;
    DM(v_NumSongs) = AR;
    
FRL:
    call SongPtrs;

    /* fill random number array, set I, L reg that are forever mapped here */
    call FillRandLUT;
    I6 = ^a_RandLUT;
    L6 = %a_RandLUT;

    /* init routines specific to a particular song */
    I5 = DM(InitGMParamsPtr);
    call (I5);

/*
 *  fill an audio buffer with 128 words of data.  once complete, wait in idle
 *  until interrupt occurs.
 */

    /* unmute audio (checked in ISR) */
    DM(v_AllMute) = M1;

FillAudioBuffer:
    I5 = DM(SetFABCNTRPtr);
    call (I5);
    CNTR = AR;
    do FAB until CE;
      
      /* set all function and output ptrs and output before 1st func call */
      call GenFXPtrInits;

      /* call all signal generators and modifiers */
      I5 = DM(GenFXPtr);
      call (I5);

      /* reset a_GenData ptr (array where gen/fx written) */
      AR = ^a_GenData;
      DM(p_GenData) = AR;

      /* call mixing/write to output array function, code in GenFX.dsp */
      I5 = DM(MixerProcPtr);
      call (I5);

FAB:  nop;

/*
 *  after all OUTBUFFLEN samples are generated, wait in idle loop until the
 *  other buffer is cleaned out.  if this check didn't exist, appears the
 *  data calculation buffer could fill too fast and the transmission buffer
 *  would be accessed before all the data was properly sent to the serial port.
 */

BufferNotEmpty:
    idle;
	AR = DM(b_FillNewBuffer);
	AR = pass AR;
	if EQ jump BufferNotEmpty;              /* was all data read from buffer? */
	
	/* reset FillNewBuffer indicator */
	DM(b_FillNewBuffer) = M0;
	
	/* swap output array.  note this is opposite polarity of that in gmISRs! */
    AX0 = ^a_LOutBuff0;
    AX1 = ^a_ROutBuff0;
    AR = DM(v_TXBuff0or1);
    AR = pass AR;
    if NE jump SetBufferPtr;
    AX0 = ^a_LOutBuff1;
    AX1 = ^a_ROutBuff1;
    
SetBufferPtr:
    DM(p_LOutBuff) = AX0;
    DM(p_RoutBuff) = AX1;

    /* call sequencer and SongCTRL and MemEnvs and other fun stuff */    
    I5 = DM(ModFuncsPtr);
    call (I5);

    /* check for next song indicator, set v_CurrSong appropriately */
    call AdvanceSong;
    
    /* shuffle data in random array */
    call ReRandomize;

    /* determine if we should exit main processing loop or keep making data */
    AR = DM(b_EndSong);
    AR = pass AR;
    if EQ jump FillAudioBuffer;

/*
 *  song(s) over, rts to return to monitor code
 */
  
EndOfSong:
    rts;
    	
.ENDMOD;


