/******************************************************************************
*
*  MemEnv.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  MemEnv1 - basic ADSR structure, runs at control rate.
*
*  current scalar
*  MemEnv1 stage
*  attack rate
*  decay rate
*  decay min
*  sustain len
*  current sustain
*  release rate
*  scalar
*  target address
*
*  decay from 1000 to 100 over 20 tics:
*
*   - attack rate:  0x7fff
*   - scalar:       1000
*   - decay rate:   ((1000-100)/(20-1))*(0x7fff/1000)=47*33
*   - decay min:    100*(0x7fff/1000)
*
*  not very inuitive, hard to calculate on the fly but should work for now
*
*  MemEnv2 - exponentially decaying sinewave.
*
*  MemEnv3 - AD with infinite hold, uses divide for calculating AD rates
*
*  current env amount
*  env counter
*  MemEnv3 stage
*  start attack value
*  end attack value
*  tics to end of attack
*  end decay value
*  tics to end of decay
*
*  MemEnv4 - ADSR with absolute peaks + duration to reach peak.  uses div.
*
******************************************************************************/

.MODULE                                     modMemEnv;

/*
 *  include files
 */


#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"

/*
 *  entry points
 */

.ENTRY      MemEnv1;

MemEnv1:
    I2 = DM(p_MemEnv1);
    MY0 = DM(I2, M1);                   /* get current scalar */
    I3 = I2;
    AX1 = DM(I2, M1);                   /* get current stage */
    I5 = ^ME1JT;
    M5 = AX1;
    modify(I5, M5);
    jump (I5);

/*
 *  I2 = ^attack rate
 *  I3 = ^current scalar
 *  MY0 = current scalar
 */
    
ME1JT:
    jump Attack1;
    jump Decay1;
    jump Sustain1;
    jump Release1;

Attack1:
    AR = DM(I2, M0);                        /* get attack rate */
    AY0 = MY0;                              /* AY0=ME scalar */
    AR = AR + AY0;                          /* inc ME scalar, dummy read */
    M2 = -2;
    modify(I2, M2);                         /* I2=^ME scalar */
    DM(I2, M1) = AR;                        /* update ME scalar */
    MY0 = AR;                               /* MY0=ME scalar */
    if AV jump ApplyME1;                    /* no overflow?  scale data */
    AY0 = 0x7fff;
    NONE = AR - AY0;
    if NE jump ApplyME1;
    
StartDecay:
    DM(I3, M0) = 1;                         /* update stage to decay */
    jump ApplyME1;

Decay1:
    AR = MY0;                               /* AR=ME scalar */
    modify(I2, M1);                         /* I2=^decay decrement */
    AY1 = DM(I2, M1);                       /* get decay rate */
    AR = AR - AY1;                          /* dec ME scalar */
    AY0 = DM(I2, M1);                       /* get dec threshold */
    M2 = -5;
    modify(I2, M2);                         /* I2=^ME scalar */
    DM(I2, M0) = AR;                        /* update ME scalar */
    NONE = AR - AY0;                        
    if GT jump Decayx;                      /* is decay thresh < curr scalar */
    
    DM(I2, M1) = AY0;                       /* if thresh<scalr, thresh=scalr */
    MY0 = AY0;                              /* ME scalar = thresh */
    DM(I3, M0) = 2;                         /* update stage to sustain */
    jump ApplyME1;

Decayx:
    MY0 = AR;
    jump ApplyME1;
    
Sustain1:
    M2 = 3;
    modify(I2, M2);
    AY1 = DM(I2, M1);                       /* get sustain len */
    AR = DM(I2, M0);                        /* get current sustain */
    AR = AR + 1;
    DM(I2, M0) = AR;                        /* sustain++ */
    NONE = AR - AY1;                        /* count<thresh? */
    if LT jump ApplyME1;                    /* if true, just scale */
    
    DM(I3, M0) = 3;                         /* else, update stage to release */
    jump ApplyME1;

Release1:
    M2 = 5;
    modify(I2, M2);
    AR = MY0;                               /* AR = ME scalar */
    AY1 = DM(I2, M1);                       /* AY1 = release rate */
    AR = AR - AY1;                          /* scalar = scalar - release rate */
    M2 = -8;
    if LE AR = pass 0;
    modify(I2, M2);
    DM(I2, M1) = AR;
    MY0 = AR;

ApplyME1:
    M2 = 7;
    modify(I3, M2);
    MX0 = DM(I3, M1);                       /* get scalar */
    MR = MX0 * MY0 (SS);
    AR = DM(I3, M1);                        /* get memory ptr */
    I5 = AR;
    DM(I5, M6) = MR1;
    
    DM(p_MemEnv1) = I3;
    
    rts;

/*----------------------------------------------------------------------------*/

/*
 *  curr scalar
 *  target addr
 *  maxout
 *  minout
 *  limit0
 *  limit1
 *  limit2
 *  decrate0
 *  int decrate cntr
 *  scalar0
 *  decrate1
 *  int decrate cntr
 *  scalar1
 *  decrate2
 *  int decrate cntr
 *  scalar2
 *  decrate3
 *  int decrate cntr
 *  scalar3
 */

.ENTRY      MemEnv2;

MemEnv2:
    I2 = DM(p_MemEnv2);
    MR1 = DM(I2, M1);                       /* curr scalar */
    AX0 = DM(I2, M1);
    AX1 = DM(I2, M1);                       /* maxout */
    AY1 = DM(I2, M1);                       /* minout */
    I5 = AX0;                               /* target addr */
    M2 = 2;
    modify(I2, M2);
    M2 = -1;
    AY0 = DM(I2, M2);
    NONE = MR1 - AY0;
    if LE jump Limit3;
    AY0 = DM(I2, M2);
    NONE = MR1 - AY0;
    if LE jump Limit2;
    AY0 = DM(I2, M2);
    NONE = MR1 - AY0;
    if LE jump Limit1;
    jump Limit0;

Limit0:
    M2 = 4;
    modify(I2, M2);

    AY0 = DM(I2, M1);                       /* get decrate counter */
    AR = DM(I2, M0);                        /* get currdec counter */
    AR = AR + 1;
    DM(I2,M1)=AR, AF=AR-AY0;                /* wr currdec cntr, update env? */
    M2 = 10;
    if LT jump NoME2Update;                 /* no ME2 update, inc ptrs */

    /* zero currdec counter */    
    M2 = -1;
    modify(I2, M2);
    DM(I2, M1) = 0;
    
    MY0 = DM(I2, M1);                       /* get scaling multiplier */
    MR = MR1 * MY0 (SS);

    M2 = -10;
    modify(I2, M2);
    DM(I2, M1) = MR1;                       /* update current scalar */
    
    AR = AX1 - AY1;                         /* maxout-minout */
    MY1 = AR;
    MR = MR1 * MY1 (RND);
    AR = MR1 + AY1;
    DM(I5, M6) = AR;
    
    !MR = MR1 * MY1 (RND);                   /* mult by maxout */
    !DM(I5, M6) = MR1;
    M2 = 18;
    modify(I2, M2);
    
    DM(p_MemEnv2) = I2;
    rts;

Limit1:
    M2 = 7;
    modify(I2, M2);

    AY0 = DM(I2, M1);                       /* get decrate counter */
    AR = DM(I2, M0);                        /* get currdec counter */
    AR = AR + 1;
    DM(I2,M1)=AR, AF=AR-AY0;                /* wr currdec cntr, update env? */
    M2 = 7;
    if LT jump NoME2Update;                 /* no ME2 update, inc ptrs */

    /* zero currdec counter */    
    M2 = -1;
    modify(I2, M2);
    DM(I2, M1) = 0;
    
    MY0 = DM(I2, M1);                       /* get scaling multiplier */
    MR = MR1 * MY0 (SS);

    M2 = -13;
    modify(I2, M2);
    DM(I2, M1) = MR1;                       /* update current scalar */
    
    AR = AX1 - AY1;                         /* maxout-minout */
    MY1 = AR;
    MR = MR1 * MY1 (RND);
    AR = MR1 + AY1;
    DM(I5, M6) = AR;
    
    !MR = MR1 * MY1 (RND);                   /* mult by maxout */
    !DM(I5, M6) = MR1;
    M2 = 18;
    modify(I2, M2);
    
    DM(p_MemEnv2) = I2;
    rts;
    
Limit2:
    M2 = 9;
    modify(I2, M2);

    AY0 = DM(I2, M1);                       /* get decrate counter */
    AR = DM(I2, M0);                        /* get currdec counter */
    AR = AR + 1;
    DM(I2,M1)=AR, AF=AR-AY0;                /* wr currdec cntr, update env? */
    M2 = 4;
    if LT jump NoME2Update;                 /* no ME2 update, inc ptrs */

    /* zero currdec counter */    
    M2 = -1;
    modify(I2, M2);
    DM(I2, M1) = 0;
    
    MY0 = DM(I2, M1);                       /* get scaling multiplier */
    MR = MR1 * MY0 (SS);

    M2 = -16;
    modify(I2, M2);
    DM(I2, M1) = MR1;                       /* update current scalar */

    AR = AX1 - AY1;                         /* maxout-minout */
    MY1 = AR;
    MR = MR1 * MY1 (RND);
    AR = MR1 + AY1;
    DM(I5, M6) = AR;

    !MR = MR1 * MY1 (RND);                   /* mult by maxout */
    !DM(I5, M6) = MR1;
    M2 = 18;
    modify(I2, M2);
    
    DM(p_MemEnv2) = I2;
    rts;
    
Limit3:
    M2 = 11;
    modify(I2, M2);

    AY0 = DM(I2, M1);                       /* get decrate counter */
    AR = DM(I2, M0);                        /* get currdec counter */
    AR = AR + 1;
    DM(I2,M1)=AR, AF=AR-AY0;                /* wr currdec cntr, update env? */
    M2 = 1;
    if LT jump NoME2Update;                 /* no ME2 update, inc ptrs */

    /* zero currdec counter */    
    M2 = -1;
    modify(I2, M2);
    DM(I2, M1) = 0;
    
    MY0 = DM(I2, M1);                       /* get scaling multiplier */
    MR = MR1 * MY0 (SS);

    M2 = -19;
    modify(I2, M2);
    DM(I2, M1) = MR1;                       /* update current scalar */

    AR = AX1 - AY1;                         /* maxout-minout */
    MY1 = AR;
    MR = MR1 * MY1 (RND);
    AR = MR1 + AY1;
    DM(I5, M6) = AR;

    !MR = MR1 * MY1 (RND);                   /* mult by maxout */
    !DM(I5, M6) = MR1;
    M2 = 18;
    modify(I2, M2);
    
    DM(p_MemEnv2) = I2;
    rts;
    
NoME2Update:
    modify(I2, M2);
    DM(p_MemEnv2) = I2;
    rts;

/*----------------------------------------------------------------------------*/

/*
 *  MemEnv3:
 *
 *  MemEnv3 stage
 *  address affected
 *  env counter
 *  start attack value
 *  end attack value
 *  total attack tics
 *  end decay value
 *  total decay tics
 */

.ENTRY      MemEnv3;

MemEnv3:
    I2 = DM(p_MemEnv3);
    AY0 = DM(I2, M1);
    AX0 = DM(I2, M1);
    I3 = AX0;
    AR = ^ME3JT;
    AR = AR + AY0;
    I5 = AR;
    jump (I5);

ME3JT:
    jump Attack3;
    jump Decay3;

/*
 *  output = start attack + ((end attack - start attack)*(curr tic))/(tot tic)
 *
 *  example:  SA=0, EA=500, tot tic = 10
 *
 *  iteration0:  0 + (500-0)*0/10=0
 *  iteration1:  0 + (500-0)*1/10=50
 *  blahblahblah
 *
 *  example:  SA=100, EA=200, tot tic = 10
 *
 *  i0:  100 + (200-100)*0/10 = 100
 */

Attack3:
    AR = DM(I2, M0);                        /* curr tic */
    MY0 = AR;
    AR = AR + 1;
    DM(I2, M1) = AR;
    AX1 = AR;                               /* keep curr tic */
    AY0 = DM(I2, M1);                       /* start attack val */
    SR0 = AY0;                              /* keep attack val */
    AX0 = DM(I2, M1);                       /* end attack val */
    AR = AX0 - AY0;                         /* end-start */
    ena M_MODE;
    MR = AR * MY0 (SS);                     /* (end-start)*currtic (int mult) */
    dis M_MODE;
    AX0 = DM(I2, M1);                       /* tot tic */
    AY1 = MR1;
    AY0 = MR0;
    AF = pass AY1;
    call USDivideNoRem;
    AR = SR0 + AY0;
    DM(I3, M0) = AR;
    AR = I2;
    AR = AR + 2;
    DM(p_MemEnv3) = AR;
    AY1 = AX0;
    NONE = AX1 - AY1;
    if LT rts;
    AR = AR - 8;
    I2 = AR;
    DM(I2, M1) = 1;                         /* start decay */
    modify(I2, M1);
    DM(I2, M1) = 0;                         /* reset cntr */
    rts;

/*
 *  output = EA-(EA-ED)*(curr tic)/(tot tic)
 *
 *  example:  EA=200, ED=150, tot tic = 10
 *
 *  iteration0:  200-(200-150)*0/10=150
 *  iteration1:  200-(200-150)*1/10=145
 *  blahblahblah
 */

Decay3:
    AR = DM(I2, M0);                        /* curr tic */
    MY0 = AR;
    AR = AR + 1;
    DM(I2, M1) = AR;
    modify(I2, M1);
    AX1 = DM(I2, M1);                       /* get end attack */
    modify(I2, M1);
    AY0 = DM(I2, M1);                       /* get end decay */
    AR = AX1 - AY0;                         /* EA-ED */
    ena M_MODE;
    MR = AR * MY0 (SS);                     /* (EA-ED)*currtic (int mult) */
    dis M_MODE;
    AX0 = DM(I2, M1);                       /* get tot tic */
    AY1 = MR1;
    AY0 = MR0;
    AF = pass AY1;
    call USDivideNoRem;
    AR = AX1 - AY0;
    DM(I3, M0) = AR;
    AR = I2;
    DM(p_MemEnv3) = AR;
    M2 = -6;
    modify(I2, M2);
    AY0 = DM(I2, M0);
    NONE = AX0 - AY0;
    if GT rts;
    DM(I2, M0) = AX0;                       /* lock decay */
    
    rts;

.ENDMOD;
