/******************************************************************************
*
*  OscComb.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  general purpose oscillator combiner function
*
*   param1:
*    0x0000:  FMMod
*    0x0001:  LoFiFMMod
*    0x0002:  xor
*    0x0003:  and
*    0x0004:  or
*    0x0005:  subtract
*
*   param2:
*    gen1 to be OscCombed
*
*   param3:
*    gen2 to be OscCombed
*
******************************************************************************/

.MODULE                                 modOscComb;

/* 
 *  include files
 */


#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"

/*
 *  entry points
 */

.ENTRY      OscCombGen;

OscCombGen:
    I2 = DM(p_OscCombGen);
    AY0 = DM(I2, M1);
    AR = ^OscCombJT;
    AR = AR + AY0;
    I5 = AR;
    jump (I5);
    
OscCombJT:
    jump XorMod;
    jump AndMod;
    jump OrMod;
    jump MultMod;
    jump LoFiMultMod;
    jump SubMod;
    jump AbsMultMod;
    jump BiggerMod;
    jump SmallerMod;

MultMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, MX0=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    MY0 = DM(I3, M0);                       /* get gen2 */
    MR = MX0 * MY0 (SS);

    DM(I7, M6) = MR1;
    DM(p_OscCombGen) = I2;
    rts;

/*****************************************************************************/

LoFiMultMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, MX0=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    MY0 = DM(I3, M0);                       /* get gen2 */
    MR = MX0 * MY0 (SS);

    DM(I7, M6) = MR0;
   
    DM(p_OscCombGen) = I2;
    rts;

/*****************************************************************************/

XorMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, AX1=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    AY1 = DM(I3, M0);                       /* get gen2 */
    AR = AX1 xor AY1;

    DM(I7, M6) = AR;
    DM(p_OscCombGen) = I2;
    rts;

/*****************************************************************************/

AndMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, AX1=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    AY1 = DM(I3, M0);                       /* get gen2 */
    AR = AX1 and AY1;

    DM(I7, M6) = AR;
    DM(p_OscCombGen) = I2;
    rts;

/*****************************************************************************/

OrMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, AX1=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    AY1 = DM(I3, M0);                       /* get gen2 */
    AR = AX1 or AY1;

    DM(I7, M6) = AR;
    DM(p_OscCombGen) = I2;
    rts;

/*****************************************************************************/

SubMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, AX1=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    AY1 = DM(I3, M0);                       /* get gen2 */
    AR = AX1 - AY1;

    DM(I7, M6) = AR;
    DM(p_OscCombGen) = I2;
    rts;

/*****************************************************************************/

AbsMultMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, AX1=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    MY1 = DM(I3, M0);                       /* get gen2 */
    AR = abs AX1;
    MR = AR * MY1 (SS);
    
    DM(I7, M6) = MR1;
    DM(p_OscCombGen) = I2;
    rts;
    
/*****************************************************************************/

BiggerMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, AX1=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    AX0 = DM(I3, M0);                       /* get gen2 */
    AR = abs AX1;
    AF = abs AX0;
    NONE = AR - AF;
    if GT jump BiggerModGen0;

BiggerModGen1:
    DM(I7, M6) = AX0;
    DM(p_OscCombGen) = I2;
    rts;
    
BiggerModGen0:
    DM(I7, M6) = AX1;
    DM(p_OscCombGen) = I2;
    rts;

/*****************************************************************************/

SmallerMod:
    AY0 = DM(I2, M1);
    AX0 = ^a_GenData;
    AR=AX0+AY0, AY0=DM(I2,M1);
    I3 = AR;
    AR=AX0+AY0, AX1=DM(I3,M0);              /* get gen1 */
    I3 = AR;
    AX0 = DM(I3, M0);                       /* get gen2 */
    AR = abs AX1;
    AF = abs AX0;
    NONE = AR - AF;
    if GT jump SmallerModGen0;

SmallerModGen1:
    DM(I7, M6) = AX1;
    DM(p_OscCombGen) = I2;
    rts;
    
SmallerModGen0:
    DM(I7, M6) = AX0;
    DM(p_OscCombGen) = I2;
    rts;
    
.ENDMOD;
