/******************************************************************************
*
*  ProbKSGen.dsp
*
*  (c) 2001, 2002, 2003 ethan bordeaux
*  syndevkit@dspmusic.org
*
*  Karplus Strong Algorithm for Plucked Strings and Other Fun Things
*
*  author:  ethan bordeaux
*
*  assumptions:
*    M0 = 0
*    M1 = 1
*    M6 = 0
*    M7 = 1
*    I6 = address some circular random number array
*
*  a_KSGen is an array of parameters for configuring KSGen
*  p_KSGen is a frame pointer to the start of the parameters for a particular
*  KSGen call
*
*    word1:  probability that circ buff will either be read direct or filtered
*            0x0000:  never filter circ buffer
*            0x7fff:  always filter circ cuffer
*    word2:  probability that samples are either added or subtracted
*            0x0000:  always subtract samples
*            0x7fff:  always add samples
*    word3:  probability that averaging factor will be pos or neg
*            0x0000:  ave factor always negative
*            0x7fff:  ave factor always positive
*    word4:  averaging factor
*    word5:  length of circular buffer upon which filtering is performed
*    word6:  pointer into circular buffer
*
*    the general formula for the output of this function is:
*
*      output = (+/-)(avefactor)*((input(n) +/- input(n-1))
*
*    word1:  will output come from this formula or direct from delay line
*    word2:  probability of sign inside equation (pos=LPF, neg=HPF)
*    word3:  probability of sign of avefactor
*    word4:  avefactor
*    word5:  freq of output
*
******************************************************************************/

.MODULE                                     modProbKSGen;

/*
 *  include files
 */


#include    ".\comsys\hdr\DSPdefs.h"
#include    ".\gen_fx\hdr\GenFX.h"

/*
 *  entry points
 */
 
.ENTRY      ProbKSGen;

ProbKSGen:
    I2 = DM(p_ProbKSGen);
    
    /* 0x0000 - never LPF noise line, 0x7fff - always LPF */
    
    AR = DM(I6, M7);                        /* get random value */
    AR=abs AR, AY0=DM(I2,M1);               /* get prob */
    NONE = AR - AY0;
    if LT jump CalcKS;                      /* if AY0 > AR, process */
    
    /* read output direct from circ buffer */
    M2 = 3;
    modify(I2, M2);
    AY0 = DM(I2, M1);
    L3 = AY0;
    AY0 = DM(I2, M0);
    I3 = AY0;
    AR = DM(I3, M1);
    AY0 = I3;
    DM(I2, M1) = AY0;
    DM(p_ProbKSGen) = I2;
    L3 = 0;
    DM(I7, M6) = AR;
    rts;
    
CalcKS:
    AX1 = DM(I2, M1);                       /* add/sub sample indicator */
    AX0 = DM(I6, M7);                       /* random number for +/- comp */
    AR = abs AX0, AY0 = DM(I2, M1);         /* prob of +/- on ave factor */
    AF = AR - AY0, AR = DM(I2, M1);         /* randnum-prob, get ave factor */
    if GT AR = - AR;
    MY0 = AR;                               /* MY0 = ave factor with sign */
        
    AY0 = DM(I2, M1);
    L3 = AY0;
    AY0 = DM(I2, M0);
    I3 = AY0;
    M2 = -1;
    
    SR0 = DM(I3, M1);
    MR=SR0*MY0(SS), SR0=DM(I3,M2);          /* scale buff(n), get buff(n+1) */
    AX0=MR1, MR=SR0*MY0(SS);                /* move buff(n), scale buff(n+1) */
    AY0 = MR1;
    AR=AX0-AY0, SR1=DM(I6, M7);             /* assume sub, get randnum */
    
    AF = abs SR1;
    NONE = AX1 - AF;
    if LT jump WriteToCircBuff;
    AR = AX0 + AY0;

WriteToCircBuff:
    DM(I3, M1) = AR;
    AY0 = I3;
    DM(I2, M1) = AY0;
    DM(p_ProbKSGen) = I2;
    L3 = 0;
    DM(I7, M6) = AR;

    rts;

.ENDMOD;